Geolocation class

Constructors

Geolocation({required double latitude, required double longitude, required double radius, required String id})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
latitude → double
final
longitude → double
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited