Geofence class

Constructors

Geofence()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

backgroundLocationUpdated ↔ StreamController<Coordinate>
getter/setter pair

Static Methods

addGeolocation(Geolocation geolocation, GeolocationEvent event) → Future<void>
Adds a geolocation for a certain geo-event
getCurrentLocation() → Future<Coordinate?>
Get the latest location the user has been.
initialize() → void
Startup; needed to setup all callbacks and prevent race-issues.
removeAllGeolocations() → Future<void>
Stops listening to all regions
removeGeolocation(Geolocation geolocation, GeolocationEvent event) → Future<void>
Stops listening to a geolocation for a certain geo-event
requestPermissions() → void
startListening(GeolocationEvent event, GeofenceCallback entry) → void
Set a callback block for a specific geo-event
startListeningForLocationChanges() → Future<void>
stopListeningForLocationChanges() → Future<void>